# Custom Schedule Form
The Custom Schedule Form feature allows you to customize a simplified standalone schedule form. Each field on the form can be configured with a default value, to allow being set from a query parameter, or to enable or disable user edits.

The URL for the Custom Schedule Form is at `/schedule`. Query parameters may be appended to the end of this URL to pre-set values for fields configured to accept query parameters. The corresponding query parameter for each field is listed underneath that field's name (for example, the query parameter for the **Title** field is `title`).

![Custom Schedule Form](ui-extensions/schedule-form/documentation.png "Custom Schedule Form")

## Options
* **Enabled**: Check this to enable the Custom Schedule form. It is disabled by default.
* **Redirect URL**: If this is non-empty, the Custom Schedule Form will redirect to this URL upon **successful** submission. Variable substitution is allowed in this URL; the allowable variables are:
  * `$title`: title of scheduled capture
  * `$eventId`: ID of scheduled capture
  * any query string parameter, including ones with no special meaning to the Custom Schedule Form (e.g. if you pass in a parameter `sessionId`, you can then use that as `$sessionId` in the redirect URL)

## Fields
The fields available in the form are a subset of the fields available in the full Schedule feature. Each field has the following options:

* **Accepts Query Parameter**: Whether the field can be set with a query parameter. The name of the query parameter is shown underneath the name of the field (for example, for the **Title** field, the query parameter is `title`)
* **User-Editable**: Whether the user is able to edit the value of the field. If this is turned off, the field is rendered as read-only and cannot be modified by the user.
* **Allowed Formats in Query String**: Lists the acceptable formats for the field when passed in as a query parameter. For time-related fields, the textual format (as formatted in the UI widget) and a numerical format are supported. For the template field, the template ID (not name) must be used; the ID of the currently selected template is shown as an example.
* **Default Value**: The default value of the field, if no query parameter is supplied. For **Start Date**, the default is always the current date and cannot be changed. For **Start Time** and **Duration**, if there are no defaults set here, then their default values will be the same as those for the standard Scheduler form (the next hour and 00:00 respectively)

## Publishing Configuration Overrides
The Custom Scheduler Form supports "publishing configuration overrides" - that is, specifying values in the scheduled event that take precedence over configuration in the template. For example, if you are publishing to Kaltura, you may wish to override the category the recording is placed in.

These are passed in through query parameters and can't be configured in the Settings UI panel for the Custom Scheduler Form. The general format of the query parameter is `publisher name.config key`. The `publisher name` is a case-insensitive substring match for the specific publisher (so, `kaltura` and `youtube` will match those respective publishers).

Examples of configuration keys that can be used (this is not an exhaustive listing):

 * `kaltura.ownerID`: overrides the "media owner id" for the Kaltura entry. The format is a Kaltura user ID (email address).
 * `kaltura.categories`: overrides the listing of categories the Kaltura entry is placed into. The format is a comma-separated list of "full" category names (e.g. `grandparent>parent>child`)
 * `matterhorn.seriesId`: override the series that the Opencast (Matterhorn) media package is placed into. The format is a series ID.
 * `matterhorn.presenter`: override the presenter name attached to the Opencast (Matterhorn) media package. The format is a string.
 * `panopto.folder`: override the folder that the Panopto entry is placed into. The format is a Panopto folder ID.
 * `ftp.url`/`sftp.url`: override the full S/FTP URL that the media package is uploaded to. The format is `[ftp|sftp]://<host>/<path>`, with the path being relative to user's home directory (precede with slash for an absolute path).
 * `youtube.category`: override the category that the YouTube video is placed into. The format is the full name of a category known to YouTube, such as `Film & Animation`.